pub enum Object {
Literal(Literal),
Function(Function),
NativeFunction(NativeFunction),
Class(Rc<RefCell<Class>>),
Instance(Rc<RefCell<Instance>>),
}Expand description
Represents an object that can be stored in a variable or returned from a function. This is an enum that wraps all the possible types of values in the language.
Variants
Literal(Literal)
Function(Function)
NativeFunction(NativeFunction)
Class(Rc<RefCell<Class>>)
Instance(Rc<RefCell<Instance>>)
Implementations